@@ -47,7 +47,17 @@ CAMLprim value caml_extunix_ctermid(value v_unit)
 CAMLprim value caml_extunix_gettid(value v_unit)
 {
   UNUSED(v_unit);
-  return Val_int(syscall(SYS_gettid));
+  size_t tid = 0;
+#if defined(WIN32)
+  tid = GetCurrentThreadId();
+#elif defined(EXTUNIX_USE_THREADID)
+  pthread_threadid_np(NULL, &tid);
+#elif defined(EXTUNIX_USE_THREAD_SELFID)
+  tid = syscall(SYS_thread_selfid);
+#else
+  tid = syscall(SYS_gettid);
+#endif
+  return Val_int(tid); /* XXX truncating to int */
 }
 
 #endif
